==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/locale/ja_JP/ja_JP-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: ja_JP-nls.php,v 1.9.2.3 2005/03/23 08:55:52 cryptographite Exp $
 *
 * Version: 1.5
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/**
 ** Native languagename
 **/
	$nls['language']['ja_JP'] = 		'&#x65e5;&#x672c;&#x8a9e; (EUC-JP)';

/**
 ** Alias for languages with different browser and gettext codes
 **/

	$nls['alias']['ja'] = 			'ja_JP';

/**
 ** Alias for languages which we substitte or send by NUKE or GeekLog
 **/

	$nls['alias']['ja_JP.EUC-JP'] =		'ja_JP' ;	
 	$nls['alias']['ja_JP.EUC'] =		'ja_JP' ;
 	$nls['alias']['japanese'] =		'ja_JP' ;
	
/**
 ** Charset
 **
 **/	
	
	$nls['charset']['ja_JP'] = 		'EUC-JP';
	
/**
 ** Multibyte charset
 **/

	$nls['multibyte']['EUC-JP'] =   	true;

?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/locale/ja_JP/ja_JP-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: ja_JP-nls.php,v 1.13.2.2 2005/09/12 22:41:00 dmolavi Exp $
 */
 
/**
 * @version	1.5.1
 * @package	Languagepack
 * @subpackage	Japanese
 */

/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz.
 * (jens@peino.de)
 */

/**
 * Native languagename
 */
	$nls['language']['ja_JP'] = 		'&#x65e5;&#x672c;&#x8a9e; (EUC-JP)';

/**
 * Aliases for languages with different browser and gettext codes
 */
	$nls['alias']['ja'] = 			'ja_JP';

/**
 * Aliases for languages which we substitte or send by NUKE, GeekLog or Mambo
 */

	$nls['alias']['ja_JP.EUC-JP'] =		'ja_JP' ;	
 	$nls['alias']['ja_JP.EUC'] =		'ja_JP' ;
 	$nls['alias']['japanese'] =		'ja_JP' ;
	
/**
 * Charset
 */	
	$nls['charset']['ja_JP'] = 		'EUC-JP';

?>
